@@ -173,11 +173,14 @@ class S3:
 
 		raise exception
 
-	def write_bytes(self, path, bytes):
+	def write(self, path, obj, mode):
 		path = self._get_path(path=path)
 		path = self._get_absolute_path(path)
-		with self.file_system.open(path=path, mode='wb') as f:
-			f.write(bytes)
+		with self.file_system.open(path=path, mode=mode) as f:
+			f.write(obj)
+
+	def write_bytes(self, path, bytes):
+		self.write(path=path, obj=bytes, mode='wb')
 
 	def get_size(self, path):
 		path = self._get_path(path=path)
@@ -203,12 +206,15 @@ class S3:
 			if isinstance(data, SparkDF):
 				return data.write.csv(path=path, encoding=encoding, **kwargs)
 
-	def read_bytes(self, path):
+	def read(self, path, mode):
 		path = self._get_path(path=path)
-		with self.file_system.open(path=path, mode='rb') as f:
+		with self.file_system.open(path=path, mode=mode) as f:
 			result = f.read()
 		return result
 
+	def read_bytes(self, path):
+		return self.read(path=path, mode='rb')
+
 	def read_csv(self, path, header=True, encoding='utf-8', **kwargs):
 		path = self._get_path(path=path)
 		path = self._get_absolute_path(path)
